@@ -268,6 +268,7 @@ class EMB():
             self.all = self.all + end
         return self.all
 
+
     def transform_OBDA(self):
         """
         Transform your triplets and prefixes inputs into OBDA (Ontology-Based Database Access).
@@ -297,9 +298,11 @@ class EMB():
             else:
                 p_curated = p
 
-            if '$(' in o:   # Change reference syntax to OBDA 
+            if '$(' in o:   # Change reference syntax to OBDA
                 o_curated = o.replace('$(', '{')
                 o_curated = o_curated.replace(")" , "}")
+                if o.startswith("$(") and d == "iri":
+                    o_curated = "<" + o_curated + ">"
             else:
                 o_curated = o
 
@@ -317,8 +320,6 @@ class EMB():
 
             for l in t[1]:
                 if not l[2] == "iri":
-                    l[2] = l[2].replace(" ", "") # TODO Check spec for string to solve this convertion
-                    l[2] = l[2].replace(":", "_") # TODO Check spec for string to solve this convertion
                     self.amaia_OBDA = self.amaia_OBDA +  " " + l[0] + " " + '"' + l[1]+ '"' + "^^" + l[2] + " ;"
                 else:
                     self.amaia_OBDA = self.amaia_OBDA +  " " + l[0] + " " + l[1] + " ;"
